==> zio-aws-emr_2.12-6.20.115.1-sources.jar: zio/aws/emr/model/InstanceGroupTimeline.scala <==
package zio.aws.emr.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.emr.model.primitives.Date
import scala.jdk.CollectionConverters._
final case class InstanceGroupTimeline(
    creationDateTime: Optional[Date] = Optional.Absent,
    readyDateTime: Optional[Date] = Optional.Absent,
    endDateTime: Optional[Date] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.InstanceGroupTimeline = {
    import InstanceGroupTimeline.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
      .builder()
      .optionallyWith(
        creationDateTime.map(value => Date.unwrap(value): Instant)
      )(_.creationDateTime)
      .optionallyWith(readyDateTime.map(value => Date.unwrap(value): Instant))(
        _.readyDateTime
      )
      .optionallyWith(endDateTime.map(value => Date.unwrap(value): Instant))(
        _.endDateTime
      )
      .build()
  }
  def asReadOnly: zio.aws.emr.model.InstanceGroupTimeline.ReadOnly =
    zio.aws.emr.model.InstanceGroupTimeline.wrap(buildAwsValue())
}
object InstanceGroupTimeline {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.InstanceGroupTimeline =
      zio.aws.emr.model.InstanceGroupTimeline(
        creationDateTime.map(value => value),
        readyDateTime.map(value => value),
        endDateTime.map(value => value)
      )
    def creationDateTime: Optional[Date]
    def readyDateTime: Optional[Date]
    def endDateTime: Optional[Date]
    def getCreationDateTime: ZIO[Any, AwsError, Date] =
      AwsError.unwrapOptionField("creationDateTime", creationDateTime)
    def getReadyDateTime: ZIO[Any, AwsError, Date] =
      AwsError.unwrapOptionField("readyDateTime", readyDateTime)
    def getEndDateTime: ZIO[Any, AwsError, Date] =
      AwsError.unwrapOptionField("endDateTime", endDateTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
  ) extends zio.aws.emr.model.InstanceGroupTimeline.ReadOnly {
    override val creationDateTime: Optional[Date] = zio.aws.core.internal
      .optionalFromNullable(impl.creationDateTime())
      .map(value => zio.aws.emr.model.primitives.Date(value))
    override val readyDateTime: Optional[Date] = zio.aws.core.internal
      .optionalFromNullable(impl.readyDateTime())
      .map(value => zio.aws.emr.model.primitives.Date(value))
    override val endDateTime: Optional[Date] = zio.aws.core.internal
      .optionalFromNullable(impl.endDateTime())
      .map(value => zio.aws.emr.model.primitives.Date(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
  ): zio.aws.emr.model.InstanceGroupTimeline.ReadOnly = new Wrapper(impl)
}

==> zio-aws-emr_2.13-5.17.125.1-sources.jar: zio/aws/emr/model/InstanceGroupTimeline.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.Date
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class InstanceGroupTimeline(
    creationDateTime: Option[Date] = None,
    readyDateTime: Option[Date] = None,
    endDateTime: Option[Date] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.emr.model.InstanceGroupTimeline = {
    import InstanceGroupTimeline.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
      .builder()
      .optionallyWith(
        creationDateTime.map(value => Date.unwrap(value): Instant)
      )(_.creationDateTime)
      .optionallyWith(readyDateTime.map(value => Date.unwrap(value): Instant))(
        _.readyDateTime
      )
      .optionallyWith(endDateTime.map(value => Date.unwrap(value): Instant))(
        _.endDateTime
      )
      .build()
  }
  def asReadOnly: zio.aws.emr.model.InstanceGroupTimeline.ReadOnly =
    zio.aws.emr.model.InstanceGroupTimeline.wrap(buildAwsValue())
}
object InstanceGroupTimeline {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.InstanceGroupTimeline =
      zio.aws.emr.model.InstanceGroupTimeline(
        creationDateTime.map(value => value),
        readyDateTime.map(value => value),
        endDateTime.map(value => value)
      )
    def creationDateTime: Option[Date]
    def readyDateTime: Option[Date]
    def endDateTime: Option[Date]
    def getCreationDateTime: ZIO[Any, AwsError, Date] =
      AwsError.unwrapOptionField("creationDateTime", creationDateTime)
    def getReadyDateTime: ZIO[Any, AwsError, Date] =
      AwsError.unwrapOptionField("readyDateTime", readyDateTime)
    def getEndDateTime: ZIO[Any, AwsError, Date] =
      AwsError.unwrapOptionField("endDateTime", endDateTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
  ) extends zio.aws.emr.model.InstanceGroupTimeline.ReadOnly {
    override val creationDateTime: Option[Date] = scala
      .Option(impl.creationDateTime())
      .map(value => zio.aws.emr.model.primitives.Date(value))
    override val readyDateTime: Option[Date] = scala
      .Option(impl.readyDateTime())
      .map(value => zio.aws.emr.model.primitives.Date(value))
    override val endDateTime: Option[Date] = scala
      .Option(impl.endDateTime())
      .map(value => zio.aws.emr.model.primitives.Date(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.InstanceGroupTimeline
  ): zio.aws.emr.model.InstanceGroupTimeline.ReadOnly = new Wrapper(impl)
}
